render

Function render 

pub fn render(
    width: usize,
    height: usize,
    coordinates: Option<&CoordinateGrid>,
    detail: Detail,
) -> RgbImage
Render a D3-like base map for the geographic extent represented by a slice. The output is geographic north-up so it can be composited directly beneath the normalized scientific data raster.