rgb_raster_with_options_for_view

Function rgb_raster_with_options_for_view 

pub fn rgb_raster_with_options_for_view(
    slice: &Slice2D,
    palette: Palette,
    limits: Option<(f64, f64)>,
    filter: Option<(f64, f64)>,
    show_land_borders: bool,
    scale: ScaleMode,
    target_width: usize,
    target_height: usize,
    selected_point: Option<(usize, usize)>,
) -> RgbImage
Rasterize a slice to a bounded viewport canvas. If the source is larger than the target, each output pixel aggregates all source cells that fall into its bin. This is the Datashader-style step that prevents a huge source array from being blurred by a final image resize.